==> qgis_0.6.0.orig.tar.gz: qgis-0.6.0/src/qgsgeomtypedialog.h <==
/***************************************************************************
                         qgsgeomtypedialog.h  -  description
                             -------------------
    begin                : October 2004
    copyright            : (C) 2004 by Marco Hugentobler
    email                : marco.hugentobler@autoform.ch
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/* $Id: qgsgeomtypedialog.h,v 1.2 2004/10/16 21:59:14 gsherman Exp $ */
#ifndef QGSGEOMTYPEDIALOG_H
#define QGSGEOMTYPEDIALOG_H

#ifdef WIN32
#include "qgsgeomtypedialogbase.h"
#else
#include "qgsgeomtypedialogbase.uic.h"
#endif //WIN32

#include "qgis.h"

class QgsGeomTypeDialog: public QgsGeomTypeDialogBase
{
  Q_OBJECT
  public:
  QgsGeomTypeDialog();
  ~QgsGeomTypeDialog();
  /**Returns the selected geometry type*/
  QGis::WKBTYPE selectedType();
  
};

#endif //QGSGEOMTYPEDIALOG_H

==> qgis_0.7.4.orig.tar.gz: qgis-0.7.4/src/qgsgeomtypedialog.h <==
/***************************************************************************
                         qgsgeomtypedialog.h  -  description
                             -------------------
    begin                : October 2004
    copyright            : (C) 2004 by Marco Hugentobler
    email                : marco.hugentobler@autoform.ch
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/* $Id: qgsgeomtypedialog.h,v 1.3 2005/04/10 12:51:30 mhugent Exp $ */
#ifndef QGSGEOMTYPEDIALOG_H
#define QGSGEOMTYPEDIALOG_H

#ifdef WIN32
#include "qgsgeomtypedialogbase.h"
#else
#include "qgsgeomtypedialogbase.uic.h"
#endif //WIN32

#include "qgis.h"

class QgsGeomTypeDialog: public QgsGeomTypeDialogBase
{
  Q_OBJECT
  public:
  QgsGeomTypeDialog();
  ~QgsGeomTypeDialog();
  /**Returns the selected geometry type*/
  QGis::WKBTYPE selectedType();
  /**Appends the chosen attribute names and types to at*/
  void attributes(std::list<std::pair<QString, QString> >& at) const;

  protected slots:
  void addAttribute();
  void removeAttribute();
  
};

#endif //QGSGEOMTYPEDIALOG_H
